#
# spec file for package ksnip
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ksnip
Version:        1.9.2
Release:        bp154.1.44
Summary:        Screenshot tool
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://github.com/DamirPorobic/ksnip
Source:         https://github.com/DamirPorobic/ksnip/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  kColorPicker-devel
BuildRequires:  kImageAnnotator-devel >= 0.5.3
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xvfb-run
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb-xfixes)

%description
Ksnip is a Qt based cross-platform screenshot tool that provides many
annotation features for your screenshots.

%lang_package

%prep
%autosetup -p1

%build
%cmake -DBUILD_TESTS=ON
%cmake_build

%install
%cmake_install
%suse_update_desktop_file -r org.ksnip.ksnip Utility DesktopUtility

%find_lang %{name} --with-qt

%check
xvfb-run make -C build test

%files
%license LICENSE.txt
%doc CHANGELOG.md CODINGSTYLE.md README.md
%{_bindir}/%{name}
%{_datadir}/applications/org.ksnip.ksnip.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/metainfo/org.ksnip.ksnip.appdata.xml

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations

%changelog
* Thu Nov 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to 1.9.2
  New
  * Set image save location on command line.
  * Add debug logging.
  * Add FTP upload.
  * Upload image via command line without opening editor.
  * Add multi-language comment option to desktop file.
  * Add MimeType of Images to desktop file.
  * Add .jpeg to open file dialog filter (File > Open).
  * Escape closes window (and exits when not using tray).
  Fixed
  * Opens a new window for each capture.
  * First cli invocation won't copy image to clipboard.
  Changed
  * Improve translation experience by using full sentences.
* Sun Sep 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to 1.9.1
  Fixed
  * Dropped temporary images appear in the open recent menu.
  * Resizing window to match content doesn't work on opening first
    image/screenshot.
  * Cursor not captured in rectangle capture.
* Sat Jun  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to 1.9.0
  New
  * Add option to select the default action for tray icon left
    click.
  * Open/Paste from clipboard via tray icon.
  * Show/hide toolbar and annotation settings with TAB.
  * Add setting for auto hiding toolbar and annotator settings.
  * Allow setting transparency of not selected snipping area
    region.
  * Resize selected rect area with arrow keys.
  * Copy a screenshot to clipboard as data URI.
  * Allow disabling tray icon notifications.
  * Provide option to open recent files.
  * Allow disabling auto resizing after first capture.
  * Drag and Drop from ksnip to other applications.
  * Add support for KDE Plasma notification service.
  * User-defined actions for taking screenshot and
    post-processing.
  * Add 'hide main window' option to actions.
  Fixed
  * Not possible to change adorner color.
  * ksnip --version output printed to stderr.
* Tue Mar 23 2021 Martin Hauke <mardnh@gmx.de>
- Update to 1.8.2
  Fixed:
  * Add missing includes to build on UNIX.
  * Ksnip starts minimized.
  * Main window still show after screenshot when corresponding
    option disabled.
  * Cancel screenshot shows main window when window was hidden.
  * Close button hidden after taking screenshot under kwin.
* Sat Mar 13 2021 ecsos <ecsos@opensuse.org>
- Update to 1.8.1
  * Changed: Allow changing adorner color for rect area selection.
    (#519)
  * Changed: Notarize ksnip for macOS. (#402)
  * Changed: Default font for numbering tool change to Arial.
    (#200)
  * Changed kImageAnnotator: Horizontally align text inside spin
    box. (#203)
  * Changed kImageAnnotator: Change zoom with mouse wheel to
    CTRL+Wheel. (#210)
  * Fixed: If file selection is cancelled during ksnip's file open
    dialog via tray icon, ksnip closes. (#503)
  * Fixed: Cancel on Quit not work when editor is hidden. (#342)
  * Fixed: Canceling rect area selection activates main window.
    (#521)
  * Fixed: Enter key doesn't finishes resizing. (#523)
  * Fixed: Missing version number in mac binaries. (#401)
  * Fixed: Canceling save dialog show the option save path in the
    header. (#545)
  * Fixed: Save-as Window does not get focus when using snap.
    (#543)
  * Fixed: Editor can not be shown again after click close icon.
    (#400)
  * Fixed: Icons and text boxes not correctly scaled under gnome
    with hdpi. (#549)
  * Fixed: Window captures include non-transparent border of
    background on Gnome. (#460)
  * Fixed: Annotating hidpi image downscales the result after being
    saved. (#172)
  * Fixed kImageAnnotator: Brazilian Portuguese translation not
    loaded. (#176)
  * Fixed kImageAnnotator: error: control reaches end of non-void
    function. (#177)
  * Fixed kImageAnnotator: Cursor in Text tool have too bad
    visibility. (#184)
  * Fixed kImageAnnotator: bumped SONAME without name change.
    (#185)
  * Fixed kImageAnnotator: Entering multiple characters at once
    moves the text cursor only for one character. (#186)
  * Fixed kImageAnnotator: Activating context menu while drawing
    item leaves item in error state. (#196)
  * Fixed kImageAnnotator: Icons not scaled on gnome with hdpi
    enabled. (#201)
  * Fixed kImageAnnotator: Text/Number Pointer and Text/Number
    Arrow don't inherit Text/Number Font in Settings. (#208)
* Mon Dec 14 2020 Martin Hauke <mardnh@gmx.de>
- Run testsuite
* Mon Dec 14 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.8.0
  New:
  * Pin screenshots in frameless windows that stay in foreground.
  * Support for unit tests.
  * Add brew cask package for ksnip.
  * Allow setting image quality when saving images.
  * Add support for cross-platform wayland screenshots using
    xdg-desktop-portal.
  * Add save and save as tab contextMenu items.
  * Add open directory context menu item on capture tabs.
  * Add copy path to clipboard context menu item on capture tabs.
  * Add option to delete saved images.
  * Add support for loading image from stdin.
  * Add screenshot options as application actions to desktop file.
  * Allow renaming existing images.
  * Make hiding main window during screenshot optional.
  * Open several files at once in tabs.
  * Allow modifying selected rectangle before making screenshot.
  * Option to keep main window hidden after a taking screenshot.
  Changed:
  * Show all Screenshot options in System Tray.
  * Upload multiple stickers at once.
  * Follow pattern for monochromatic systray icon.
  * Pin window shows default cursor when mouse over it.
  * Cancel snipping area if no selection made after 60 sec.
  * Allow removing imgur account.
  Fixed:
  * zh_Hans translation won't load.
  * Ksnip only saves the upper right part of the screenshot with
    HiDPI.
  * Main window not resized with new captures.
  * Brazilian Portuguese translation not loaded.
* Fri Jul 31 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.7.3
  * Install svg icon file in hicolor theme dir instead of
    usr/share/pixmaps/.
- Update to version 1.7.2
  Changed:
  * Stop upload script when process writes to stderr.
  * Upload script uses regex to select output for clipboard.
  Fixed:
  * Ksnip becomes unresponsive when file dropped into it.
  * Ksnip window always visible on screenshots on Gnome Wayland.
* Thu Jun 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.7.1
  Fixed:
  * User not prompted to save when taking new screenshot without
    tabs.
* Fri Jun 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.7.0
  New:
  * Pasting image or path to image from clipboard.
  * Save to same file when editing existing image.
  * Support for PrtScrn hotkey.
  * Auto save new screenshot.
  * Remember file for already saved images.
  * Add support for drag and drop images into ksnip.
  * Insert embedded image into an existing screenshot.
  * Show screenshots in tabs.
  * Add Maximize Window Button in Print Preview.
  * Click on toast message opens content.
  * Remember last used folder in the save file dialog.
  * Custom script for upload images.
  * Disable single global hotkey by clearing the shortcut.
  * Run ksnip as single instance.
  * Add option for disabling tabs.
  * Add count wildcard format for filename.
  * Allow to change upload imgur URI.
  * Support for adding custom stickers.
  Changed:
  * Save As option was added and useInstantSave config was removed.
  * Disable scroll down with zero value in timeout widget.
  * Disable unsupported capture modes in settings.
  Fixed:
  * Compilation error with Qt 5.15.
  * Undo and redo translation reverts back to English.
  * When 'Capture Save Location' is not set, ksnip fails to save.
  * Connections that required ssl not working on AppImages.
  * Main window hangs when pressing Esc on selecting screenshot
    area state.
  * Unable to resize ksnip window.
  * Rectangle picker is not closed with -r -s switches when mouse
    button is released.
- Remove patch (fixed upstream):
  * 0001-Fix-compilation-error-with-Qt-5.15-279.patch
* Fri Jun  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.6.2
  * Changed: Add missing plugs to silence snap socket warnings.
  * Fixed: Window decoration and alt+tab menu show Wayland generic icon on KDE Plasma.
  * Fixed: Logout canceled by 'ksnip' under KDE.
  * Fixed: Ksnip not displayed on the monitor (off screen).
  * Fixed: CTRL+Q to quit Ksnip not working.
  * Fixed: Global Hotkeys not working with activated Num and Caps Lock under X11.
  * Fixed: Meta Global Hotkey under X11 not working.
- Add upstream patch:
  * 0001-Fix-compilation-error-with-Qt-5.15-279.patch
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.6.1
  * Allow opening link directly to image without opening in browser.
  * Always use transparent snipping area background for Wayland.
  * Disable unavailable config options.
* Sun Feb  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.6.0
  New:
  * Make captured cursor an item which can be moved and deleted.
  * Add watermarks to annotated image.
  * Add crop button to toolbar.
  * Add undo and redo button on toolbar.
  * Make if watermark is rotated a config option.
  * Do not open image uploaded to imgur in browser.
  * Add shortcuts for taking screenshots.
  * Add Global HotKeys for X11.
  * Provide option to use previous capture area.
  * Add System Tray Icon.
  * Show tray icon notification after image was uploaded to
    imgur or saved.
  * Add support for Open-with.
  * Open ksnip minimized to tray.
  Changed:
  * Change copy icon.
  * Before discarding ask if user want save or not or cancel.
  * Shortcut for imgur upload was changed to Shift + i.
  Fixed:
  * Wildcards in path are not resolved.
  * CLI arg --rectarea doesn't work.
  * Add shortcut for File Menu in Main Menu.
  * Prompt to save before exit enabled now by default.
  * Configuration Window not translated.
  * ksnip opens anyway with -s option specified.
  * Open Image with full size window doesn't resize main window.
  * Can't work correctly when using scaled display.
  * ksnip opens outside desktop if last saved position was on n
    longer available monitor.
  * Window demaximize when taking a new screenshot.
  * Add support for Chinese Text Input.
- Drop patch:
  * ksnip-fix-install-dir.patch (not longer needed)
* Mon Jan 13 2020 Martin Hauke <mardnh@gmx.de>
- Drop superflous "Recommends: %%{name}-lang"
* Sun Dec 29 2019 Martin Hauke <mardnh@gmx.de>
- Package stable release, version 1.5.0
- Add patch:
  * ksnip-fix-install-dir.patch
* Thu Jun  6 2019 Андрей Алыпов <and.november@opensuse.org>
- initial package (version 1.6.0) for openSUSE
